==> haskell-lens-aeson-1.2.3-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-aeson
version:              1.2.3
visibility:           public
id:                   lens-aeson-1.2.3-LadbKRgz0P7H90zSbOV4so
key:                  lens-aeson-1.2.3-LadbKRgz0P7H90zSbOV4so
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Data, JSON, Lenses
abi:                  c6aa29bd03ef7b91e95b8b6f62b1c9d7
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lens-aeson-1.2.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lens-aeson-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.2.3-LadbKRgz0P7H90zSbOV4so
depends:
    aeson-2.1.2.1-4zJKowqIccG16mc5i0l3g8 base-4.16.4.0
    bytestring-0.11.4.0 lens-5.2.3-JA5mwEMSFUnB8cIUYPsCHA
    scientific-0.3.7.0-1UiZtxIrrRCI5SqK0NgMSR text-1.2.5.0
    text-short-0.1.6-AYOb4fnSnJYAuSEfq3V3Qm
    unordered-containers-0.2.20-A3yVeSkjdcGAgke7XFfywE
    vector-0.13.1.0-G7FmTKS6EuOC4CxSRTf251

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.2.3-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-aeson
version:              1.2.3
visibility:           public
id:                   lens-aeson-1.2.3-DsJI8KQDTq18JNllYDZmRo
key:                  lens-aeson-1.2.3-DsJI8KQDTq18JNllYDZmRo
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Data, JSON, Lenses
abi:                  d0da465ec917c21657992eebcde409b6
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.2.8/site-local/lens-aeson-1.2.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lens-aeson-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.2.3-DsJI8KQDTq18JNllYDZmRo
depends:
    aeson-2.1.2.1-3lugcDour1r4V4jv6ZKvkq base-4.16.4.0
    bytestring-0.11.4.0 lens-5.2.3-LJCKq2CVV0OBzhsqfjAjcB
    scientific-0.3.7.0-7p41gUaaSP7BrDOTk8p39O text-1.2.5.0
    text-short-0.1.6-BlBwhLn6RgVGU82Vvt7Q74
    unordered-containers-0.2.20-2iyjFoh2jxC3XOaFpxfD6Q
    vector-0.13.1.0-HRMJcTNtHmH9PMIsGjP73X

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
